==> haskell-puremd5-2.1.3-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-puremd5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pureMD5
version:              2.1.3
visibility:           public
id:                   pureMD5-2.1.3-IglofNHWYC1HdhSCcYXGHb
key:                  pureMD5-2.1.3-IglofNHWYC1HdhSCcYXGHb
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.

description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.

category:             Data, Cryptography
abi:                  90e0ba9fcfa6fbf32f336e1b9c9535ae
exposed:              True
exposed-modules:      Data.Digest.Pure.MD5
import-dirs:          /usr/lib/ghc-8.10.3/site-local/pureMD5-2.1.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/pureMD5-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/pureMD5-2.1.3
hs-libraries:         HSpureMD5-2.1.3-IglofNHWYC1HdhSCcYXGHb
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.12.0
    cereal-0.5.8.1-GAgNOTi0dTnED5BVJ0WdTc
    crypto-api-0.13.3-CMo6wpUywSyQ1mzS8jqj1
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe

haddock-interfaces:   /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html:         /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-puremd5-2.1.3-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-puremd5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pureMD5
version:              2.1.3
visibility:           public
id:                   pureMD5-2.1.3-ExzmqyVKdUxDOJQURc3L5j
key:                  pureMD5-2.1.3-ExzmqyVKdUxDOJQURc3L5j
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.

description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.

category:             Data, Cryptography
abi:                  fb3501e0b13752accf91e129c0626f09
exposed:              True
exposed-modules:      Data.Digest.Pure.MD5
import-dirs:          /usr/lib/ghc-8.10.3/site-local/pureMD5-2.1.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/pureMD5-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/pureMD5-2.1.3
hs-libraries:         HSpureMD5-2.1.3-ExzmqyVKdUxDOJQURc3L5j
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.12.0
    cereal-0.5.8.1-GAgNOTi0dTnED5BVJ0WdTc
    crypto-api-0.13.3-29xf6phcoYS3UxI8fy8p1u
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C

haddock-interfaces:   /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html:         /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
